pub struct ConfigPolicyUpdate {
pub allow_uncertain_quality: bool,
pub retention_days: Option<u32>,
pub mrft_delay_secs: Option<u32>,
pub poll_interval_ms: Option<u64>,
pub timeout_secs: Option<u64>,
pub op_timeout_secs: Option<u64>,
pub restore_timeout_secs: Option<u64>,
}Expand description
Config-page-owned settings that can be patched in place while preserving every unrelated key and comment in the source TOML.
Fields
allow_uncertain_quality: boolretention_days: Option<u32>mrft_delay_secs: Option<u32>poll_interval_ms: Option<u64>timeout_secs: Option<u64>op_timeout_secs: Option<u64>restore_timeout_secs: Option<u64>Implementations
Sourceimpl ConfigPolicyUpdate
impl ConfigPolicyUpdate
pub fn tuning(&self) -> TuningConfig