pub fn load_config(explicit_path: Option<&Path>) -> Result<BhtuneConfig>Expand description
Resolve and load the bhtune config: an explicit --config path if given, otherwise the
platform’s auto-discovered path (silently falls back to defaults if none of the relevant
environment variables are set, or if the discovered file doesn’t exist).